@@ -1001,6 +1001,10 @@ WidgetFactory.moveChildren = function(sourceWidget, targetWidget, settingsGroup)
                 }
             }
 
+            if (isOfType(w, RMathLineEdit)) {
+                WidgetFactory.initLineEditInfoTools(w);
+            }
+
             a = targetWidget.addWidget(w);
             a.objectName = w.objectName + "Action";
             ret.push(a);
@@ -1043,6 +1047,9 @@ WidgetFactory.adjustIcons = function(includeBasePath, widget) {
     }
 };
 
+WidgetFactory.initLineEditInfoTools = function(mathLineEdit) {
+};
+
 /**
  * Adds an "insert symbol" menu entry to the context menu of the given
  * line edit.
